@@ -106,10 +106,10 @@ void LatexDelegate::setEditorData(QWidget *editor, const QModelIndex &index) con
         if (entry) {
             QString text = index.model()->data(index).toString();
             if (text.startsWith(QLatin1String("$$")) && text.endsWith(QLatin1String("$$"))) {
-                entry->setText(text.mid(2, text.count() - 4));
+                entry->setText(text.mid(2, text.size() - 4));
                 m_checkBox->setChecked(true);
             } else if (text.startsWith(QStringLiteral("§§")) && text.endsWith(QStringLiteral("§§"))) {
-                entry->setText(text.mid(2, text.count() - 4));
+                entry->setText(text.mid(2, text.size() - 4));
                 m_checkBox->setChecked(false);
             } else {
                 entry->setText(QString());
@@ -130,7 +130,7 @@ void LatexDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, con
         if (entry) {
             QString text = entry->text();
             if (m_checkBox->isChecked()) {
-                model->setData(index, QString("$$" + text + "$$"));
+                model->setData(index, QString(QStringLiteral("$$") + text + QStringLiteral("$$")));
             } else {
                 model->setData(index, QString(QStringLiteral("§§") + text + QStringLiteral("§§")));
             }
