@@ -22,7 +22,7 @@ public:
 private Q_SLOTS:
     void playAudio();
     void stopAudio();
-    void playerStateChanged(QMediaPlayer::State newState);
+    void playerStateChanged(QMediaPlayer::PlaybackState newState);
 
 private:
     QMediaPlayer *m_player; ///< media object for the files
